cci-fix.patch

application/octet-stream

Filename: cci-fix.patch
Type: application/octet-stream
Part: 0
Message: Re: ddd

Patch

Format: unified
File+
src/backend/access/transam/xact.c 3 3
diff --git a/src/backend/access/transam/xact.c b/src/backend/access/transam/xact.c
index d430e662e6..b37510c24f 100644
--- a/src/backend/access/transam/xact.c
+++ b/src/backend/access/transam/xact.c
@@ -683,12 +683,12 @@ GetCurrentCommandId(bool used)
 	if (used)
 	{
 		/*
 		 * Forbid setting currentCommandIdUsed in parallel mode, because we
 		 * have no provision for communicating this back to the master.  We
 		 * could relax this restriction when currentCommandIdUsed was already
 		 * true at the start of the parallel operation.
 		 */
-		Assert(CurrentTransactionState->parallelModeLevel == 0);
+		Assert(!IsParallelWorker());
 		currentCommandIdUsed = true;
 	}
 	return currentCommandId;
@@ -683,12 +683,12 @@ GetCurrentCommandId(bool used)
 	{
 		/*
-		 * Forbid setting currentCommandIdUsed in parallel mode, because we
-		 * have no provision for communicating this back to the master.  We
+		 * Forbid setting currentCommandIdUsed in a parallel worker, because
+		 * we have no provision for communicating this back to the master.  We
 		 * could relax this restriction when currentCommandIdUsed was already
 		 * true at the start of the parallel operation.